==> kubernetes-model-autoscaling-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ObjectMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

public class ObjectMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent<A> {

    private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder describedObject;
    private MetricIdentifierBuilder metric;
    private MetricTargetBuilder target;

    public ObjectMetricSourceFluentImpl() {
    }

    public ObjectMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSource instance) {
        this.withDescribedObject(instance.getDescribedObject()); 
        this.withMetric(instance.getMetric()); 
        this.withTarget(instance.getTarget()); 
    }

    
/**
 * This method has been deprecated, please use method buildDescribedObject instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference getDescribedObject() {
        return this.describedObject!=null?this.describedObject.build():null;
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference buildDescribedObject() {
        return this.describedObject!=null?this.describedObject.build():null;
    }

    public A withDescribedObject(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference describedObject) {
        _visitables.get("describedObject").remove(this.describedObject);
        if (describedObject!=null){ this.describedObject= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(describedObject); _visitables.get("describedObject").add(this.describedObject);} return (A) this;
    }

    public Boolean hasDescribedObject() {
        return this.describedObject != null;
    }

    public A withNewDescribedObject(String apiVersion,String kind,String name) {
        return (A)withDescribedObject(new CrossVersionObjectReference(apiVersion, kind, name));
    }

    public ObjectMetricSourceFluent.DescribedObjectNested<A> withNewDescribedObject() {
        return new DescribedObjectNestedImpl();
    }

    public ObjectMetricSourceFluent.DescribedObjectNested<A> withNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
        return new DescribedObjectNestedImpl(item);
    }

    public ObjectMetricSourceFluent.DescribedObjectNested<A> editDescribedObject() {
        return withNewDescribedObjectLike(getDescribedObject());
    }

    public ObjectMetricSourceFluent.DescribedObjectNested<A> editOrNewDescribedObject() {
        return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder().build());
    }

    public ObjectMetricSourceFluent.DescribedObjectNested<A> editOrNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
        return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): item);
    }

    
/**
 * This method has been deprecated, please use method buildMetric instead.
 * @return The buildable object.
 */
@Deprecated public MetricIdentifier getMetric() {
        return this.metric!=null?this.metric.build():null;
    }

    public MetricIdentifier buildMetric() {
        return this.metric!=null?this.metric.build():null;
    }

    public A withMetric(MetricIdentifier metric) {
        _visitables.get("metric").remove(this.metric);
        if (metric!=null){ this.metric= new MetricIdentifierBuilder(metric); _visitables.get("metric").add(this.metric);} return (A) this;
    }

    public Boolean hasMetric() {
        return this.metric != null;
    }

    public ObjectMetricSourceFluent.MetricNested<A> withNewMetric() {
        return new MetricNestedImpl();
    }

    public ObjectMetricSourceFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item) {
        return new MetricNestedImpl(item);
    }

    public ObjectMetricSourceFluent.MetricNested<A> editMetric() {
        return withNewMetricLike(getMetric());
    }

    public ObjectMetricSourceFluent.MetricNested<A> editOrNewMetric() {
        return withNewMetricLike(getMetric() != null ? getMetric(): new MetricIdentifierBuilder().build());
    }

    public ObjectMetricSourceFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item) {
        return withNewMetricLike(getMetric() != null ? getMetric(): item);
    }

    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public MetricTarget getTarget() {
        return this.target!=null?this.target.build():null;
    }

    public MetricTarget buildTarget() {
        return this.target!=null?this.target.build():null;
    }

    public A withTarget(MetricTarget target) {
        _visitables.get("target").remove(this.target);
        if (target!=null){ this.target= new MetricTargetBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
    }

    public Boolean hasTarget() {
        return this.target != null;
    }

    public ObjectMetricSourceFluent.TargetNested<A> withNewTarget() {
        return new TargetNestedImpl();
    }

    public ObjectMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item) {
        return new TargetNestedImpl(item);
    }

    public ObjectMetricSourceFluent.TargetNested<A> editTarget() {
        return withNewTargetLike(getTarget());
    }

    public ObjectMetricSourceFluent.TargetNested<A> editOrNewTarget() {
        return withNewTargetLike(getTarget() != null ? getTarget(): new MetricTargetBuilder().build());
    }

    public ObjectMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item) {
        return withNewTargetLike(getTarget() != null ? getTarget(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ObjectMetricSourceFluentImpl that = (ObjectMetricSourceFluentImpl) o;
        if (describedObject != null ? !describedObject.equals(that.describedObject) :that.describedObject != null) return false;
        if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
        if (target != null ? !target.equals(that.target) :that.target != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(describedObject,  metric,  target,  super.hashCode());
    }

    public class DescribedObjectNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluentImpl<ObjectMetricSourceFluent.DescribedObjectNested<N>> implements ObjectMetricSourceFluent.DescribedObjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder builder;

            DescribedObjectNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this, item);
                        
            }

            DescribedObjectNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withDescribedObject(builder.build());
            }

            public N endDescribedObject() {
                return and();
            }
    }


    public class MetricNestedImpl<N> extends MetricIdentifierFluentImpl<ObjectMetricSourceFluent.MetricNested<N>> implements ObjectMetricSourceFluent.MetricNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final MetricIdentifierBuilder builder;

            MetricNestedImpl(MetricIdentifier item) {
                this.builder = new MetricIdentifierBuilder(this, item);
                        
            }

            MetricNestedImpl() {
                this.builder = new MetricIdentifierBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withMetric(builder.build());
            }

            public N endMetric() {
                return and();
            }
    }


    public class TargetNestedImpl<N> extends MetricTargetFluentImpl<ObjectMetricSourceFluent.TargetNested<N>> implements ObjectMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final MetricTargetBuilder builder;

            TargetNestedImpl(MetricTarget item) {
                this.builder = new MetricTargetBuilder(this, item);
                        
            }

            TargetNestedImpl() {
                this.builder = new MetricTargetBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withTarget(builder.build());
            }

            public N endTarget() {
                return and();
            }
    }


}

==> kubernetes-model-autoscaling-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ObjectMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

public class ObjectMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent<A> {

    private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder describedObject;
    private MetricIdentifierBuilder metric;
    private MetricTargetBuilder target;

    public ObjectMetricSourceFluentImpl() {
    }

    public ObjectMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSource instance) {
        this.withDescribedObject(instance.getDescribedObject()); 
        this.withMetric(instance.getMetric()); 
        this.withTarget(instance.getTarget()); 
    }

    
/**
 * This method has been deprecated, please use method buildDescribedObject instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference getDescribedObject() {
        return this.describedObject!=null?this.describedObject.build():null;
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference buildDescribedObject() {
        return this.describedObject!=null?this.describedObject.build():null;
    }

    public A withDescribedObject(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference describedObject) {
        _visitables.get("describedObject").remove(this.describedObject);
        if (describedObject!=null){ this.describedObject= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(describedObject); _visitables.get("describedObject").add(this.describedObject);} return (A) this;
    }

    public Boolean hasDescribedObject() {
        return this.describedObject != null;
    }

    public A withNewDescribedObject(String apiVersion,String kind,String name) {
        return (A)withDescribedObject(new CrossVersionObjectReference(apiVersion, kind, name));
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.DescribedObjectNested<A> withNewDescribedObject() {
        return new DescribedObjectNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.DescribedObjectNested<A> withNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
        return new DescribedObjectNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.DescribedObjectNested<A> editDescribedObject() {
        return withNewDescribedObjectLike(getDescribedObject());
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.DescribedObjectNested<A> editOrNewDescribedObject() {
        return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.DescribedObjectNested<A> editOrNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
        return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): item);
    }

    
/**
 * This method has been deprecated, please use method buildMetric instead.
 * @return The buildable object.
 */
@Deprecated public MetricIdentifier getMetric() {
        return this.metric!=null?this.metric.build():null;
    }

    public MetricIdentifier buildMetric() {
        return this.metric!=null?this.metric.build():null;
    }

    public A withMetric(MetricIdentifier metric) {
        _visitables.get("metric").remove(this.metric);
        if (metric!=null){ this.metric= new MetricIdentifierBuilder(metric); _visitables.get("metric").add(this.metric);} return (A) this;
    }

    public Boolean hasMetric() {
        return this.metric != null;
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.MetricNested<A> withNewMetric() {
        return new MetricNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item) {
        return new MetricNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.MetricNested<A> editMetric() {
        return withNewMetricLike(getMetric());
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.MetricNested<A> editOrNewMetric() {
        return withNewMetricLike(getMetric() != null ? getMetric(): new MetricIdentifierBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item) {
        return withNewMetricLike(getMetric() != null ? getMetric(): item);
    }

    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public MetricTarget getTarget() {
        return this.target!=null?this.target.build():null;
    }

    public MetricTarget buildTarget() {
        return this.target!=null?this.target.build():null;
    }

    public A withTarget(MetricTarget target) {
        _visitables.get("target").remove(this.target);
        if (target!=null){ this.target= new MetricTargetBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
    }

    public Boolean hasTarget() {
        return this.target != null;
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.TargetNested<A> withNewTarget() {
        return new TargetNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item) {
        return new TargetNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.TargetNested<A> editTarget() {
        return withNewTargetLike(getTarget());
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.TargetNested<A> editOrNewTarget() {
        return withNewTargetLike(getTarget() != null ? getTarget(): new MetricTargetBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item) {
        return withNewTargetLike(getTarget() != null ? getTarget(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ObjectMetricSourceFluentImpl that = (ObjectMetricSourceFluentImpl) o;
        if (describedObject != null ? !describedObject.equals(that.describedObject) :that.describedObject != null) return false;
        if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
        if (target != null ? !target.equals(that.target) :that.target != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(describedObject,  metric,  target,  super.hashCode());
    }

    public class DescribedObjectNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.DescribedObjectNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.DescribedObjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder builder;

            DescribedObjectNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this, item);
                        
            }

            DescribedObjectNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withDescribedObject(builder.build());
            }

            public N endDescribedObject() {
                return and();
            }
    }


    public class MetricNestedImpl<N> extends MetricIdentifierFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.MetricNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.MetricNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final MetricIdentifierBuilder builder;

            MetricNestedImpl(MetricIdentifier item) {
                this.builder = new MetricIdentifierBuilder(this, item);
                        
            }

            MetricNestedImpl() {
                this.builder = new MetricIdentifierBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withMetric(builder.build());
            }

            public N endMetric() {
                return and();
            }
    }


    public class TargetNestedImpl<N> extends MetricTargetFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.TargetNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final MetricTargetBuilder builder;

            TargetNestedImpl(MetricTarget item) {
                this.builder = new MetricTargetBuilder(this, item);
                        
            }

            TargetNestedImpl() {
                this.builder = new MetricTargetBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withTarget(builder.build());
            }

            public N endTarget() {
                return and();
            }
    }


}
